==> open-xchange-util-custom_1.2.0.orig.tar.bz2: open-xchange-util-custom-1.2.0/com.openexchange.util.custom/src/com/openexchange/util/activator/impl/UpdateTaskServiceWithDependencies.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.util.activator.impl;

import javax.annotation.ParametersAreNonnullByDefault;
import com.openexchange.groupware.update.DefaultUpdateTaskProviderService;
import com.openexchange.groupware.update.UpdateTaskProviderService;
import com.openexchange.groupware.update.UpdateTaskV2;
import com.openexchange.util.activator.ServiceDependencyResolver;


/**
 * {@link UpdateTaskServiceWithDependencies}
 *
 * @author <a href="mailto:pascal.bleser@open-xchange.com">Pascal Bleser</a>
 * @since v1.0.2
 */
@ParametersAreNonnullByDefault
public final class UpdateTaskServiceWithDependencies<U extends UpdateTaskV2>
extends ServiceWithDependenciesTemplate<UpdateTaskProviderService, DefaultUpdateTaskProviderService> {
    
    public static final <X extends UpdateTaskV2> ServiceWithDependencies<DefaultUpdateTaskProviderService> find(final Class<X> updateTaskClass) {
        return new UpdateTaskServiceWithDependencies<X>(updateTaskClass, ConstructorServiceWithDependencies.find(updateTaskClass, UpdateTaskV2.class));
    }
    
    private ServiceWithDependencies<U> swd;
    
    public UpdateTaskServiceWithDependencies(final Class<U> updateTaskClass,
        final ServiceWithDependencies<U> swd) {
        super(
            DefaultUpdateTaskProviderService.class,
            UpdateTaskProviderService.class,
            swd.serviceDependencies(),
            swd.serviceSetClasses(),
            swd.serviceListingClasses()
        );
        this.swd = swd;
    }
    
    @Override
    public DefaultUpdateTaskProviderService createInstance(final ServiceDependencyResolver resolver) {
        final U task = swd.createInstance(resolver);
        final DefaultUpdateTaskProviderService service = new DefaultUpdateTaskProviderService(task);
        return service;
    }

}

==> open-xchange-util-custom_1.2.1.orig.tar.bz2: open-xchange-util-custom-1.2.1/com.openexchange.util.custom/src/com/openexchange/util/activator/impl/UpdateTaskServiceWithDependencies.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.util.activator.impl;

import javax.annotation.ParametersAreNonnullByDefault;
import com.openexchange.groupware.update.DefaultUpdateTaskProviderService;
import com.openexchange.groupware.update.UpdateTaskProviderService;
import com.openexchange.groupware.update.UpdateTaskV2;
import com.openexchange.util.activator.ServiceDependencyResolver;


/**
 * {@link UpdateTaskServiceWithDependencies}
 *
 * @author <a href="mailto:pascal.bleser@open-xchange.com">Pascal Bleser</a>
 * @since v1.0.2
 */
@ParametersAreNonnullByDefault
public final class UpdateTaskServiceWithDependencies<U extends UpdateTaskV2>
extends ServiceWithDependenciesTemplate<UpdateTaskProviderService, DefaultUpdateTaskProviderService> {
    
    public static final <X extends UpdateTaskV2> ServiceWithDependencies<DefaultUpdateTaskProviderService> find(final Class<X> updateTaskClass) {
        return new UpdateTaskServiceWithDependencies<X>(updateTaskClass, ConstructorServiceWithDependencies.find(updateTaskClass, UpdateTaskV2.class));
    }
    
    private ServiceWithDependencies<U> swd;
    
    public UpdateTaskServiceWithDependencies(final Class<U> updateTaskClass,
        final ServiceWithDependencies<U> swd) {
        super(
            DefaultUpdateTaskProviderService.class,
            UpdateTaskProviderService.class,
            swd.mandatoryServiceDependencies(),
            swd.optionalServiceDependencies(),
            swd.serviceSetClasses(),
            swd.serviceListingClasses()
        );
        this.swd = swd;
    }
    
    @Override
    public DefaultUpdateTaskProviderService createInstance(final ServiceDependencyResolver resolver) {
        final U task = swd.createInstance(resolver);
        final DefaultUpdateTaskProviderService service = new DefaultUpdateTaskProviderService(task);
        return service;
    }

}
